#!/usr/bin/env python

from setuptools import find_packages, setup

setup(
    name="trash123",
    version="0.1",
    description="For testing purposes",
    long_description=open("README.md", encoding="utf8").read(),
    long_description_content_type="text/markdown",
    python_requires=">=3.11",
    zip_safe=False,
)

